Include "mri2D.inc"
Group{
  Body=Region[2] ;
  Jcur=Region[1] ;
  Air = Region[3] ;
  bnd = Region[4];

  Domain = Region[{Body,Air,Jcur}] ;
  Lossy= Region[{Body,Jcur}];
}

Function{
  f = 0.3e9;
  c=3e8;
  nu0=1/(4.0e-7*Pi);
  epsilon0=8.84e-12;
  pisur2RM=Atan[1.0]*2.0/RM;
  R[]=Sqrt[(X[]-x0)^2+(Y[]-y0)^2];
  M[]=(X[]-x0-(Y[]+y0)*Sqrt[-1])*pisur2RM*Cos[R[]*pisur2RM];
  
  
  epsilon[Air]=epsilon0;
  epsilon[Lossy]=epsilon0*Sqrt[50];
  
  sigma[Lossy]=0.1;
  js0[Jcur]=M[]*Sqrt[-1];
  
}

Jacobian{
{ Name JSur ; Case { { Region All ; Jacobian Sur ; } } }
}
Integration {
  { Name I1 ;
    Case {
      { Type Gauss ;
        Case {
	  { GeoElement Point       ; NumberOfPoints  1 ; }
	  { GeoElement Line        ; NumberOfPoints  3 ; }
	  { GeoElement Triangle    ; NumberOfPoints  4 ; }
	  { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
	  { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
	  { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
	  { GeoElement Prism       ; NumberOfPoints  6 ; }
	}
      }
    }
  }

  { Name I2 ;
    Case {
      { Type Gauss ;
        Case {
	  { GeoElement Point       ; NumberOfPoints  1 ; }
	  { GeoElement Line        ; NumberOfPoints  4 ; }
	  { GeoElement Triangle    ; NumberOfPoints  7 ; }
	  { GeoElement Quadrangle  ; NumberOfPoints  7 ; }
	  { GeoElement Tetrahedron ; NumberOfPoints  15 ; }
	  { GeoElement Hexahedron  ; NumberOfPoints  34 ; }
	  { GeoElement Prism       ; NumberOfPoints  21 ; }
	}
      }
    }
  }
  { Name I3 ;
    Case {
      { Type Gauss ;
        Case {
          { GeoElement Point ; NumberOfPoints  1 ; }
          { GeoElement Line ; NumberOfPoints  4 ; }
          { GeoElement Triangle ; NumberOfPoints  6 ; }
          { GeoElement Quadrangle ; NumberOfPoints 7 ; }
          { GeoElement Tetrahedron ; NumberOfPoints 15 ; }
          { GeoElement Hexahedron ; NumberOfPoints 34 ; }
        }
      }
    }
  }
}

Constraint {
	{ Name ElectricField; Type Assign;
	  Case { {Region bnd; Value 0.0;}}
	}
}
FunctionSpace {
  //Electric field
  { Name Scalar_ez; Type Form0;
    BasisFunction {
      { Name se; NameOfCoef ee; Function BF_Node;
        Support Domain ; Entity EdgesOf[All]; }
    }
    Constraint {
      { NameOfCoef ee; EntityType EdgesOf ; NameOfConstraint ElectricField; }
    }
  }



}

Formulation {
 { Name Microwave_e ; Type FemEquation;
    Quantity {
      { Name e; Type Local;  NameOfSpace Scalar_ez; }
    }
    Equation {
      Galerkin { [ nu0 * Dof{Grad e} , {Grad e} ];
        In Domain; Integration I3; Jacobian JSur;  }
      
      Galerkin { DtDof [ sigma[] * Dof{e} , {e} ];
       In Lossy ; Integration I3; Jacobian JSur;  }
      Galerkin { DtDtDof [ epsilon[] * Dof{e} , {e} ];
        In Domain; Integration I3; Jacobian JSur;  }

      Galerkin { DtDof [  js0[] , {e} ];
        In Jcur; Integration I3; Jacobian JSur;  }

     
    }
  }
}


Resolution {
  { Name Microwave_e_BC;
    System {
      { Name B; 
        NameOfFormulation Microwave_e; 
        Type ComplexValue;
        Frequency f;}
    }
    Operation {
      Generate[B]; Solve[B]; SaveSolution[B];
    }
  }
}

PostProcessing {
  { Name Microwave_e ; NameOfFormulation Microwave_e ;
    Quantity {
      { Name e  ;  
        Value { 
          Local{ [{e}] ; In Domain ; Jacobian JSur;} } }
    }
  }
}

PostOperation {

  { Name Microwave_e ; NameOfPostProcessing Microwave_e ;
    Operation {
      Print[ e,  OnElementsOf Region[{Domain}],  File "toto.pos" ] ;    }
  }

}

